@@ -5,6 +5,8 @@ import org.dom4j.Document;
 import org.dom4j.Element;
 
 import java.net.URL;
+import java.net.Authenticator;
+import java.net.PasswordAuthentication;
 import java.util.List;
 
 /**
@@ -19,6 +21,11 @@ public class Main {
         // we'll just take the root object as an example
         URL url = new URL("http://deadlock.netbeans.org/hudson/api/xml");
 
+        // if you are calling security-enabled Hudson and
+        // need to invoke operations and APIs that are protected,
+        // consult the 'SecuredMain" class
+        // in this package for an example using HttpClient.
+
         // read it into DOM.
         Document dom = new SAXReader().read(url);
 
